aboutsummaryrefslogtreecommitdiffstats
path: root/activemodel/lib/active_model/dirty.rb
diff options
context:
space:
mode:
authorRafael Mendonça França <rafaelmfranca@gmail.com>2014-07-15 16:00:50 -0300
committerRafael Mendonça França <rafaelmfranca@gmail.com>2014-07-15 16:04:31 -0300
commit66d0a0153578ce760d822580c5b8c0b726042ac2 (patch)
tree9307990257adef0f8908d8ef150677ef87bf2947 /activemodel/lib/active_model/dirty.rb
parent101cf688987ec39c05859061677f99b43facc2a2 (diff)
downloadrails-66d0a0153578ce760d822580c5b8c0b726042ac2.tar.gz
rails-66d0a0153578ce760d822580c5b8c0b726042ac2.tar.bz2
rails-66d0a0153578ce760d822580c5b8c0b726042ac2.zip
Deprecate ActiveModel::Dirty#reset_changes in favor of #clear_changes_information
This method name is causing confusion with the `reset_#{attribute}` methods. While `reset_name` set the value of the name attribute for the previous value the `reset_changes` only discard the changes and previous changes.
Diffstat (limited to 'activemodel/lib/active_model/dirty.rb')
-rw-r--r--activemodel/lib/active_model/dirty.rb16
1 files changed, 12 insertions, 4 deletions
diff --git a/activemodel/lib/active_model/dirty.rb b/activemodel/lib/active_model/dirty.rb
index dc6088a39a..e93ce05e40 100644
--- a/activemodel/lib/active_model/dirty.rb
+++ b/activemodel/lib/active_model/dirty.rb
@@ -15,7 +15,7 @@ module ActiveModel
# * Call <tt>attr_name_will_change!</tt> before each change to the tracked
# attribute.
# * Call <tt>changes_applied</tt> after the changes are persisted.
# * Call <tt>reset_changes</tt> when you want to reset the changes
# information.
# * Call <tt>undo_changes</tt> when you want to restore previous data.
#
@@ -37,11 +37,14 @@ module ActiveModel
#
# def save
# # do persistence work
+ #
# changes_applied
# end
#
# def reload!
- # reset_changes
+ # # get the values from the persistence layer
+ #
+ # clear_changes_information
# end
#
# def rollback!
@@ -184,12 +187,17 @@ module ActiveModel
@changed_attributes = ActiveSupport::HashWithIndifferentAccess.new
end
- # Removes all dirty data: current changes and previous changes.
- def reset_changes # :doc:
+ # Clear all dirty data: current changes and previous changes.
+ def clear_changes_information # :doc:
@previously_changed = ActiveSupport::HashWithIndifferentAccess.new
@changed_attributes = ActiveSupport::HashWithIndifferentAccess.new
end
+ def reset_changes
+ ActiveSupport::Deprecation.warn "#reset_changes is deprecated and will be removed on Rails 5. Please use #clear_changes_information instead."
+ clear_changes_information
+ end
+
# Restore all previous data.
def undo_changes # :doc:
changed_attributes.each_key { |attr| reset_attribute! attr }
@@ -15,7 +15,7 @@ module ActiveModel
# attribute.
# * Call <tt>changes_applied</tt> after the changes are persisted.
- # * Call <tt>reset_changes</tt> when you want to reset the changes
+ # * Call <tt>clear_changes_information</tt> when you want to reset the changes
# information.
# * Call <tt>undo_changes</tt> when you want to restore previous data.